==> cons-commons-1.0.72.tgz: package/lib/utils/basicR.dao.ts <==
import { Connection, DeepPartial, Repository } from 'typeorm';
import { JoinFilter, HavingFilter, OrderByAction, LimitOffsetAction, QueryUtils } from '../utils/query.utils';
import { BasicREntity } from '../entities/basicR.type';
import { QueryDeepPartialEntity } from 'typeorm/query-builder/QueryPartialEntity';

export abstract class BasicRDAO<T extends BasicREntity> {
    protected abstract getDatabase();

    protected abstract getTableName(): string;

    private database = this.getDatabase();

    private connection;

    protected getRepository(connection: Connection): Repository<T> {
        this.connection = connection;
        return connection.getRepository(this.getTableName());
    }

    public getConnection(): Connection {
        return this.connection;
    }

    public async findByFilter(
        joinFilters?: JoinFilter[],
        havingFilters?: HavingFilter[],
        orderByActions?: OrderByAction[],
        limitOffsetAction?: LimitOffsetAction,
        full?: boolean,
    ): Promise<Array<T>> {
        console.debug(`BasicService.findByFilter.`);

        try {
            const qb = this.getRepository(await this.database.getConnection()).createQueryBuilder(this.getTableName());

            QueryUtils.defineFilters(qb, joinFilters, orderByActions, limitOffsetAction, havingFilters);

            console.debug(qb.getSql());

            if (full) {
                const entities = await qb.loadAllRelationIds().getMany();
                return Promise.resolve(!Array.isArray(entities) ? [] : entities);
            }

            const entities = await qb.getMany();
            return Promise.resolve(!Array.isArray(entities) ? [] : entities);
        } catch (ex) {
            console.error(ex);
            return Promise.reject(ex);
        }
    }

    public async drop(): Promise<void> {
        const qb = this.getRepository(await this.database.getConnection());
        qb.query(`DELETE FROM \`${this.getTableName()}\`;`);
    }

    public async count(
        joinFilters?: JoinFilter[],
        havingFilters?: HavingFilter[],
        orderByActions?: OrderByAction[],
        limitOffsetAction?: LimitOffsetAction): Promise<number> {
        console.debug(`BasicService.count.`);

        try {
            const qb = this.getRepository(await this.database.getConnection()).createQueryBuilder(this.getTableName());

            QueryUtils.defineFilters(qb, joinFilters, orderByActions, limitOffsetAction, havingFilters);

            console.debug(qb.getSql());

            const count = await qb.getCount();
            return Promise.resolve(count);
        } catch (ex) {
            console.error(ex);
            return Promise.reject(ex);
        }
    }

    public async getByFilter(
        joinFilters?: JoinFilter[],
        havingFilters?: HavingFilter[],
        orderByActions?: OrderByAction[],
        limitOffsetAction?: LimitOffsetAction,
        full?: boolean): Promise<T | undefined> {
        console.debug(`BasicService.getByFilter.`);

        try {
            const qb = this.getRepository(await this.database.getConnection()).createQueryBuilder(this.getTableName());

            QueryUtils.defineFilters(qb, joinFilters, orderByActions, limitOffsetAction, havingFilters);

            console.debug(qb.getSql());

            if (full) {
                const entity = await qb.loadAllRelationIds().getOne();
                return Promise.resolve(entity);
            }
            
            const entity = await qb.getOne();
            return Promise.resolve(entity);
        } catch (ex) {
            console.error(ex);
            return Promise.reject(ex);
        }
    }

    public async get(id: number): Promise<T | undefined> {
        const havingFilters = Array<HavingFilter>();
        havingFilters.push(new HavingFilter(this.getTableName() + '.id = ' + '"' + id + '"', undefined, true));

        return this.getByFilter(
            undefined,
            havingFilters,
            undefined,
            undefined,
            true);
    }

    public async save(
        entity: DeepPartial<T>): Promise<string> {
        console.debug(`BasicService.save. Value: ${JSON.stringify(entity)}`);

        try {
            const newEntity = await this.getRepository(await this.database.getConnection()).save(entity);
            return Promise.resolve(newEntity.id);
        } catch (ex) {
            console.error(ex);
            return Promise.reject(ex);
        }
    }

    public async update(
        entity: QueryDeepPartialEntity<T>,
        id: number): Promise<void> {
        console.debug(`BasicService.update. Value: ${JSON.stringify(entity)}`);

        try {
            // entity.id = id;
            await this.getRepository(await this.database.getConnection()).update(id, entity);
            return Promise.resolve();
        } catch (ex) {
            console.error(ex);
            return Promise.reject(ex);
        }
    }

    public async remove(
        id: number): Promise<void> {
        console.debug(`BasicService.remove. Value: ${JSON.stringify(id)}`);

        try {
            await this.getRepository(await this.database.getConnection()).delete(id);
            return Promise.resolve();
        } catch (ex) {
            console.error(ex);
            return Promise.reject(ex);
        }
    }
}

==> cons-commons-1.0.114.tgz: package/lib/utils/basicR.dao.ts <==
import { Connection, DeepPartial, Repository } from 'typeorm';
import { JoinFilter, HavingFilter, OrderByAction, LimitOffsetAction, QueryUtils } from '../utils/query.utils';
import { BasicREntity } from '../entities/basicR.type';
import { QueryDeepPartialEntity } from 'typeorm/query-builder/QueryPartialEntity';

export abstract class BasicRDAO<T extends BasicREntity> {
    protected abstract getDatabase();

    protected abstract getTableName(): string;

    private database = this.getDatabase();

    private connection;

    protected getRepository(connection: Connection): Repository<T> {
        this.connection = connection;
        return connection.getRepository(this.getTableName());
    }

    public async getConnection(): Promise<Connection> {
        if (!this.connection) {
            this.connection = await this.database.getConnection();
        }
        return this.connection;
    }

    public async findByFilter(
        joinFilters?: JoinFilter[],
        havingFilters?: HavingFilter[],
        orderByActions?: OrderByAction[],
        limitOffsetAction?: LimitOffsetAction,
        full?: boolean,
    ): Promise<Array<T>> {
        console.debug(`BasicService.findByFilter.`);

        if(!havingFilters) {
            havingFilters = [];
        }
        havingFilters.push(new HavingFilter(`${this.getTableName()}.deleted = false`, undefined, true));

        try {
            const qb = this.getRepository(await this.database.getConnection()).createQueryBuilder(this.getTableName());

            QueryUtils.defineFilters(qb, joinFilters, orderByActions, limitOffsetAction, havingFilters);

            console.debug(qb.getSql());

            if (full) {
                const entities = await qb.loadAllRelationIds().getMany();
                return Promise.resolve(!Array.isArray(entities) ? [] : entities);
            }

            const entities = await qb.getMany();
            return Promise.resolve(!Array.isArray(entities) ? [] : entities);
        } catch (ex) {
            console.error(ex);
            return Promise.reject(ex);
        }
    }

    public async drop(): Promise<void> {
        const qb = this.getRepository(await this.database.getConnection());
        qb.query(`DELETE FROM \`${this.getTableName()}\`;`);
    }

    public async count(
        joinFilters?: JoinFilter[],
        havingFilters?: HavingFilter[],
        orderByActions?: OrderByAction[],
        limitOffsetAction?: LimitOffsetAction): Promise<number> {
        console.debug(`BasicService.count.`);

        if(!havingFilters) {
            havingFilters = [];
        }
        havingFilters.push(new HavingFilter(`${this.getTableName()}.deleted = false`, undefined, true));

        try {
            const qb = this.getRepository(await this.database.getConnection()).createQueryBuilder(this.getTableName());

            QueryUtils.defineFilters(qb, joinFilters, orderByActions, limitOffsetAction, havingFilters);

            console.debug(qb.getSql());

            const count = await qb.getCount();
            return Promise.resolve(count);
        } catch (ex) {
            console.error(ex);
            return Promise.reject(ex);
        }
    }

    public async getByFilter(
        joinFilters?: JoinFilter[],
        havingFilters?: HavingFilter[],
        orderByActions?: OrderByAction[],
        limitOffsetAction?: LimitOffsetAction,
        full?: boolean): Promise<T | undefined> {
        console.debug(`BasicService.getByFilter.`);

        if(!havingFilters) {
            havingFilters = [];
        }
        havingFilters.push(new HavingFilter(`${this.getTableName()}.deleted = false`, undefined, true));

        try {
            const qb = this.getRepository(await this.database.getConnection()).createQueryBuilder(this.getTableName());

            QueryUtils.defineFilters(qb, joinFilters, orderByActions, limitOffsetAction, havingFilters);

            console.debug(qb.getSql());

            if (full) {
                const entity = await qb.loadAllRelationIds().getOne();
                return Promise.resolve(entity);
            }
            
            const entity = await qb.getOne();
            return Promise.resolve(entity);
        } catch (ex) {
            console.error(ex);
            return Promise.reject(ex);
        }
    }

    public async get(id: any): Promise<T | undefined> {
        const havingFilters = Array<HavingFilter>();
        havingFilters.push(new HavingFilter(`${this.getTableName()}.id = "${id}"`, undefined, true));

        return this.getByFilter(
            undefined,
            havingFilters,
            undefined,
            undefined,
            true);
    }

    public async save(
        entity: DeepPartial<T>): Promise<string> {
        console.debug(`BasicService.save. Value: ${JSON.stringify(entity)}`);

        try {
            const newEntity = await this.getRepository(await this.database.getConnection()).save(entity);
            return Promise.resolve(newEntity.id);
        } catch (ex) {
            console.error(ex);
            return Promise.reject(ex);
        }
    }

    public async update(
        entity: QueryDeepPartialEntity<T>,
        id: any): Promise<void> {
        console.debug(`BasicService.update. Value: ${JSON.stringify(entity)}`);

        try {
            // entity.id = id;
            await this.getRepository(await this.database.getConnection()).update(id, entity);
            return Promise.resolve();
        } catch (ex) {
            console.error(ex);
            return Promise.reject(ex);
        }
    }

    public async remove(
        id: any): Promise<void> {
        console.debug(`BasicService.remove. ${this.getTableName()} ${typeof this} Value: ${JSON.stringify(id)}`);
        const entity = <any>await this.get(id);
        if(entity) {
            entity.deleted = true;
            if(entity.isActive){
                entity.isActive=false;
            }
            try {
                await this.update(entity, id);
            } catch (ex) {
                console.error(ex);
                return Promise.reject(ex);
            }
        }
        return Promise.resolve();
    }
}
